@@ -1,35 +1,40 @@
-from ast_monitor.mainwindow import Ui_MainWindow
-from PyQt5.QtCore import QThread, pyqtSignal, QTimer
-from PyQt5 import QtCore, QtGui, QtWidgets
-from PyQt5.QtWidgets import *
-from PyQt5.QtGui import *
-from PyQt5.QtCore import pyqtSlot
-from PyQt5.QtCore import QProcess
-import os
 from datetime import datetime
 import geopy.distance
+import os
+from pyqt_feedback_flow.feedback import (
+    AnimationDirection,
+    AnimationType,
+    TextFeedback
+)
+from PyQt5 import QtWidgets
+from PyQt5.QtCore import pyqtSlot, QDateTime, QTimer
+from PyQt5.QtWidgets import QMessageBox
+
 from ast_monitor.classes import SensorData
-from pyqt_feedback_flow.feedback import Feedback
+from ast_monitor.mainwindow import Ui_MainWindow
+
 
 TICK_TIME = 2**6
 
 
 class AST(QtWidgets.QMainWindow, Ui_MainWindow):
     """
-    Main class that represents the interface between computer and athlete.
-
+    Main class that represents the interface between computer and athlete.\n
     Args:
-        hr_data_path: path to file for storing HR data
-        gps_path: path to file for storing GPS data
+        hr_data_path (str):
+            path to file for storing HR data
+        gps_path (str):
+            path to file for storing GPS data
     """
 
-    def __init__(self, hr_data_path, gps_data_path):
+    def __init__(self, hr_data_path: str, gps_data_path: str) -> None:
         """
-        Initialisation method for AST class.
-
+        Initialisation method for AST class.\n
         Args:
-            hr_data_path: path to file for storing HR data
-            gps_path: path to file for storing GPS data
+            hr_data_path (str):
+                path to file for storing HR data
+            gps_path (str):
+                path to file for storing GPS data
         """
         QtWidgets.QMainWindow.__init__(self)
         Ui_MainWindow.__init__(self)
@@ -37,29 +42,27 @@ class AST(QtWidgets.QMainWindow, Ui_MainWindow):
 
         self.hr_data_path = hr_data_path
         self.gps_data_path = gps_data_path
-
-        self.time_series = []  # storing all the data in this struct
-
+        self.time_series = []  # Storing all the data in this struct
         self.hr_data_collection = []
 
-        # show HR in real time
+        # Show HR in real time.
         self.timer = QTimer()
         self.timer.timeout.connect(self.real_time_hr)
         self.timer.start(1000)
 
-        # taking values from the sensors
+        # Taking values from the sensors.
         # self.build_time_series()
 
-        # shutdown the computer
+        # Shutdown the computer.
         self.shutdown.clicked.connect(self.shutdown_now)
 
-        # on clicked buttons
+        # On clicked buttons.
         self.tracker = QTimer()
         self.tracker.setInterval(TICK_TIME)
         self.tracker.timeout.connect(self.tick)
         self.do_reset()
 
-        # menu buttons
+        # Menu buttons.
         self.actionAbout_program.triggered.connect(self.about)
         self.actionLicense.triggered.connect(self.license)
         self.actionDisclaimer.triggered.connect(self.disclaimer)
@@ -69,78 +72,131 @@ class AST(QtWidgets.QMainWindow, Ui_MainWindow):
 
         self.stop_tracking.clicked.connect(self.endTracker)
 
-    def startTracking(self):
+    def startTracking(self) -> None:
         """
         Start tracker for tracking the workout.
         """
         self.startTracker()
         self.tracking_flag = True
 
-        # show simple notification that workout just started
-        self._feedback = Feedback(text="Workout started!")
-        self._feedback.show()
+        # Show simple notification that workout just started.
+        self._feedback = TextFeedback(text='Workout started!')
+        self._feedback.show(
+            AnimationType.VERTICAL,
+            AnimationDirection.UP,
+            time=3000
+        )
 
-    def startTracker(self):
+    def startTracker(self) -> None:
+        """
+        Starting tracker.
+        """
         self.tracker.start()
 
-    def endTracker(self):
+    def endTracker(self) -> None:
+        """
+        Ending tracker.
+        """
         self.tracker.stop()
         self.tracking_flag = False
 
-    def tick(self):
+    def tick(self) -> None:
+        """
+        Incrementing time and displaying it on the stopwatch on each tick.
+        """
         self.track_time += TICK_TIME / 1000
         self.display_stopwatch()
 
-    def display_stopwatch(self):
+    def display_stopwatch(self) -> None:
+        """
+        Displaying the stopwatch.
+        """
         self.watch.display(
-            "%d:%05.2f" %
-            (self.track_time //
-             60,
-             self.track_time %
-             60))
+            '%d:%05.2f'
+            % (self.track_time // 60, self.track_time % 60)
+        )
 
-    def update_distance(self):
+    def update_distance(self) -> None:
+        """
+        Calculating and displaying distance.
+        """
         dist = self.calculate_distance()
-        self.total_distance.setText(str(dist))
+        
+        # If there is no distance made yet, 0 is displayed.
+        if not dist:
+            self.total_distance.setText('0.00 km')
+        else:
+            rounded_dist = round(dist, 2)
+            dist_str = '{:.2f}'.format(rounded_dist)
+            self.total_distance.setText(dist_str + ' km')
 
-    def update_ascent(self):
+    def update_ascent(self) -> None:
+        """
+        Calculating and updating ascent.
+        """
         pass
 
-    def update_average_hr(self):
+    def update_average_hr(self) -> None:
+        """
+        Calculating and displaying average heart rate.
+        """
         avhr = str(self.calculate_avhr())
         self.average_hr.setText(avhr)
 
-    def update_interval_hr(self):
+    def update_interval_hr(self) -> None:
+        """
+        Calculating and displaying interval heart rate.
+        """
         pass
 
     @pyqtSlot()
-    def do_reset(self):
+    def do_reset(self) -> None:
+        """
+        Reset of the stopwatch.
+        """
         self.track_time = 0
         self.display_stopwatch()
 
-    def showtrackingTime(self):
+    def showtrackingTime(self) -> None:
+        """
+        Displaying tracking time.
+        """
         time = QDateTime.currentDateTime()
         timeDisplay = time.toString('yyyy-MM-dd hh:mm:ss dddd')
         self.label.setText(timeDisplay)
 
-    def shutdown_now(self):
-        os.system("shutdown now -h")
+    def shutdown_now(self) -> None:
+        """
+        Shutdown of the system.
+        """
+        os.system('shutdown now -h')
 
-    def startTimer(self):
+    def startTimer(self) -> None:
+        """
+        Starting timer.
+        """
         self.timer.start(1000)
 
-    def endTimer(self):
+    def endTimer(self) -> None:
+        """
+        Ending timer.
+        """
         self.timer.stop()
 
-    def get_current_time(self):
+    def get_current_time(self) -> datetime:
+        """
+        Getting current time.\n
+        Returns:
+            datetime: current time
+        """
         now = datetime.now()
-        current_time = now.strftime("%H:%M:%S")
+        current_time = now.strftime('%H:%M:%S')
         return current_time
 
-    # collect, GPS data, HR data and current time
-    def build_time_series(self):
+    def build_time_series(self) -> None:
         """
-        Build time series from the collected GPS data, HR data and current time.
+        Build time series from the collected
+        GPS data, HR data and current time.
         """
         HR = self.return_curr_hr()
         GPS_LON, GPS_LAT, GPS_ALT = self.return_curr_gps()
@@ -151,17 +207,21 @@ class AST(QtWidgets.QMainWindow, Ui_MainWindow):
                 GPS_LON,
                 GPS_LAT,
                 GPS_ALT,
-                TIME))
+                TIME
+            )
+        )
 
     @pyqtSlot()
-    def real_time_hr(self):
+    def real_time_hr(self) -> int:
         """
-        Show current HR value.
+        Show current HR value.\n
+        Returns:
+            int: current heart rate
         """
         hr_val = self.return_curr_hr()
         self.current_hr.setText(str(hr_val))
 
-        # build_time_series in case tracker is enabled
+        # Build_time_series in case tracker is enabled.
         if self.tracking_flag:
             self.build_time_series()
             self.update_distance()
@@ -169,59 +229,66 @@ class AST(QtWidgets.QMainWindow, Ui_MainWindow):
 
         return int(hr_val)
 
-    def return_curr_hr(self):
+    def return_curr_hr(self) -> int:
         """
-        Get current HR data from file.
+        Get current HR data from file.\n
+        Returns:
+            int: current heart rate
         """
-        # if file is empty
-        # should be improved
+        # If file is empty.
+        # Note: should be improved.
         if os.stat(self.hr_data_path).st_size == 0:
             return 0
 
-        with open(self.hr_data_path, "r") as ins:
+        with open(self.hr_data_path, 'r') as ins:
             array = []
             for line in ins:
                 array.append(int(line.rstrip()))
 
-            # use data for calculation of average HR
+            # Use data for calculation of average HR.
             self.calculate_avhr(array)
-
             final = str(array[-1])
 
         return int(final)
 
-    def return_curr_gps(self):
+    def return_curr_gps(self) -> tuple:
         """
-        Get current GPS data from file.
+        Get current GPS data from file.\n
+        Returns:
+            tuple(float, float, float):
         """
-        # if file is empty
-        # should be improved
+        # If file is empty.
+        # Note: should be improved.
         if os.stat(self.gps_data_path).st_size == 0:
             return 0.0, 0.0, 0.0
 
-        with open(self.gps_data_path, "r") as ins:
+        with open(self.gps_data_path, 'r') as ins:
             array = []
             for line in ins:
                 array.append(line)
 
             final1 = str(array[-1].rstrip())
             final = final1.split(";")
+
         return float(final[0]), float(final[1]), float(final[2])
 
-    def calculate_avhr(self, hr_data):
+    def calculate_avhr(self, hr_data: list) -> float:
         """
-        Calculate average HR of workout
-
+        Calculate average HR of the workout.\n
         Args:
-            hr_data: a list of all HR values of workout.
+            hr_data (list):
+                a list of all HR values of the workout
+        Returns:
+            float: average heart rate of the workout
         """
         avhr = sum(hr_data) / len(hr_data)
-
         return avhr
 
-    def calculate_distance(self):
+    def calculate_distance(self) -> float:
         """
-        Calculate distance of workout.
+        Calculate distance of workout.\n
+        Returns:
+            float: total distance
         """
         total_distance = 0.0
         if (len(self.time_series) < 5):
@@ -236,25 +303,25 @@ class AST(QtWidgets.QMainWindow, Ui_MainWindow):
 
             return round((total_distance / 1000), 3)
 
-    def about(self):
+    def about(self) -> None:
         """
         Show information about application.
         """
         msg = QMessageBox()
         msg.setIcon(QMessageBox.Information)
-        msg.setText("Developed by I. Fister Jr., 2021")
-        msg.setWindowTitle("About this application")
-        retval = msg.exec_()
+        msg.setText('Developed by I. Fister Jr., 2021')
+        msg.setWindowTitle('About this application')
+        msg.exec_()
 
-    def license(self):
+    def license(self) -> None:
         """
         Show license information.
         """
         msg = QMessageBox()
         msg.setIcon(QMessageBox.Information)
-        msg.setText("Licensed under MIT license!")
-        msg.setWindowTitle("License info!")
-        retval = msg.exec_()
+        msg.setText('Licensed under MIT license!')
+        msg.setWindowTitle('License info!')
+        msg.exec_()
 
     def disclaimer(self):
         """
@@ -262,7 +329,9 @@ class AST(QtWidgets.QMainWindow, Ui_MainWindow):
         """
         msg = QMessageBox()
         msg.setIcon(QMessageBox.Information)
-        msg.setWindowTitle("Disclaimer")
+        msg.setWindowTitle('Disclaimer')
         msg.setDetailedText(
-            "This framework is provided as-is, and there are no guarantees that it fits your purposes or that it is bug-free. Use it at your own risk!")
-        retval = msg.exec_()
+            'This framework is provided as-is, and there are no guarantees '
+            'that it fits your purposes or that it is bug-free. Use it at '
+            'your own risk!')
+        msg.exec_()
